import sys
import time
import loadwave

def main():
    arg = sys.argv[1]
    if(arg == "r4isy-1"):
        HOST = "245.141.151.141"
        connectserver(arg, HOST)
    
    else:
        print("This server is invalid.")
        exit()
        """elif(arg == "r4isy-2"):
        HOST = "20.250.2.200"
        print()"""
    
def connectserver(server, servername ="r4isy-1"):
    print("Connecting to the server. - " + servername)
    connectserverld()

@loadwave.process
def connectserverld():
    time.sleep(3.5)
    print("A connection error occurred. The server is down or under maintenance. Please try again later.")


from setuptools import setup, find_packages

setup(
    name='r4isy',
    version='0.0.1',
    packages=find_packages(),
    install_requires=[
        "loadwave",
        "importlib"
    ],
    entry_points={
        'console_scripts': [
            'connect=r4isy.connect:main',
        ],
    },
    author='r4isydev',
    author_email='info@r4isy.com',
    description='a lib',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)
